@@ -1,4 +1,4 @@
-# $Id: Assembler.pm,v 1.56 2010/11/21 16:32:49 Paulo Exp $
+# $Id: Assembler.pm,v 1.57 2013/07/26 02:16:14 Paulo Exp $
 
 package CPU::Z80::Assembler;
 
@@ -25,7 +25,7 @@ use Regexp::Trie;
 
 use vars qw(@EXPORT $verbose);
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 our $verbose;
 our $fill_byte = 0xFF;
 
@@ -51,8 +51,8 @@ use base qw(Exporter);
   $binary = z80asm('#include <file.asm>');
   open($fh, $file); $binary = z80asm(sub {<$fh>});
 
-  $lines  = z80preprocessor(@asm_lines); $line  = $lines->get;
-  $tokens = z80lexer(@asm_lines);        $token = $tokens->get;
+  $lines  = z80preprocessor(@asm_lines); $line  = $lines->next;
+  $tokens = z80lexer(@asm_lines);        $token = $tokens->next;
 
 =head1 DESCRIPTION
 
@@ -156,7 +156,7 @@ of file includes and handles the %line and #line lines generated by external
 preprocessors like cpp or nasm. 
 
 The result is a
-L<Asm::Preproc::Stream|Asm::Preproc::Stream> 
+L<Iterator::Simple::Lookahead|Iterator::Simple::Lookahead> 
 of L<Asm::Preproc::Line|Asm::Preproc::Line> objects that contain each of 
 the input lines of the input.
 
@@ -170,7 +170,7 @@ sub z80preprocessor {
 	$pp->include_list(@input);
 	
 	# create a new stream to handle "INCLUDE" statement
-	return Asm::Preproc::Stream->new( 
+	return Iterator::Simple::Lookahead->new( 
 		sub {
 			while (1) {
 				my $line = $pp->getline
@@ -197,7 +197,7 @@ This function takes as parameter a list of either text lines to parse,
 or iterators that return text lines to parse.
 
 It calls C<z80preprocessor> to split the input into a 
-L<Asm::Preproc::Stream|Asm::Preproc::Stream>
+L<Iterator::Simple::Lookahead|Iterator::Simple::Lookahead>
 of L<Asm::Preproc::Line|Asm::Preproc::Line> objects representing the source
 lines of the Z80 assembly language program.
 
@@ -231,7 +231,8 @@ my $SYMBOLS_RE = _regexp("
 
 #------------------------------------------------------------------------------
 # lexer
-my $lexer = Asm::Preproc::Lexer->new(
+my $lexer = Asm::Preproc::Lexer->new;
+$lexer->make_lexer(
 	
 	# ignore comments and blanks except newline
 	COMMENT	=> qr/ ; .* /ix,			undef,		
@@ -284,9 +285,9 @@ my $lexer = Asm::Preproc::Lexer->new(
 sub _lexer_stream {
 	my($input) = @_;
 	my $this_lexer = $lexer->clone;		# compile $lexer only once
-	$this_lexer->input( $input );		# define our input stream
+	$this_lexer->from( $input );		# define lexer input stream
 	
-	return $this_lexer->stream;
+	return $this_lexer;
 }
 
 #------------------------------------------------------------------------------
